@@ -197,6 +197,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
       }
     """
     print(f"receiver: {receiver}, amount: {amount}, run_mode: {run_mode}, chain: {chain}, token: {token}, kwargs: {kwargs}, step: {step}")
+    token_raw = token
     info = None
     executor = kwargs.get("executor")
     redis_client = kwargs.get("redis_client")
@@ -231,7 +232,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
               'receiver': receiver,
               'amount': amount,
               'chain': chain,
-              'token': token,
+              'token': token_raw,
               'run_mode': run_mode
             }
             next_action_data = ActionData(func='transfer', group='transfer', params=next_params)
@@ -269,7 +270,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
               'receiver': to,
               'amount': amount,
               'chain': chain,
-              'token': token,
+              'token': token_raw,
               'run_mode': run_mode
             }
             next_action_data = ActionData(func='transfer', group='transfer', params=next_params)
@@ -372,7 +373,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
             'receiver': to,
             'amount': amount,
             'chain': chain,
-            'token': token,
+            'token': token_raw,
             'run_mode': run_mode
           }
           next_action_data = ActionData(func='transfer', group='transfer', params=params)
@@ -400,7 +401,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
             'receiver': to,
             'amount': amount,
             'chain': chain,
-            'token': token,
+            'token': token_raw,
             'run_mode': run_mode
           }
           action_data = ActionData(func='transfer', group='transfer', params=params)
